WriteError

Enum WriteError 

#[non_exhaustive]
pub enum WriteError { OutOfSequence, OutOfSpace, }
Error type for manipulation of MessageMut mutable messages.

This is presented externally as an internal server error, but has enough structure to be useful for debugging through dbg!().

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


OutOfSequence



OutOfSpace