MessageMut

Struct MessageMut 

pub struct MessageMut<EM: MessageBufferMut> { /* private fields */ }
A CoAP message that resides in contiguous mutable memory.

Exceeding the guarantees of MutableWritableMessage, this does allow some out-of-sequence invocations: Even after payload has been written to, options can be added, memmove’ing (right-rotating) the written payload, as long as it does not truncate it. This is needed to accommodate libOSCORE’s requirements (because while libOSCORE can also do without a memmove-ing message, that’d require its use through WritableMessage to adhere to in-OSCORE write sequence conventions, making the whole situation no easier on the coap-message abstraction). Data will only be moved if an option is added after content has been set, so this comes at no runtime cost for those who do not need it. (It may be later turned into a feature. Then, the memmove code would be removed; carrying the latest option number in the WriteState should come at no extra cost due to the struct’s content and alignment).

When viewed through the coap_message::ReadableMessage trait, this will behave as if writing had stopped (but still allows writes after reading); in particular, the payload will be shown as empty. (This may be obvious from most points of view, but when coming from a coap_message::MutableWritableMessage point of view where payloads can only ever be truncated and not made longer, this clarification is relevant).

The type is covariant over its lifetime. This also means that we can never add any methods where we move references into Self, but we don’t do this anyway: The lifetime 'a only serves to describe the memory backing it; data is moved in there, not stored by reference. This property is accessible through downcasting.

Invariants

The message in the EM is always a well-formed CoAP message. This is upheld by construction or checked at creation time (when existing messages are consumed). As the underlying MessageBufferMut can be implemented without unsafe, this crate can only panic (but not invoke undefined behavior) when that is violated.

Implementations

Source

impl<'a> MessageMut<SliceBufferMut<'a>>

pub fn new_in_slice(code: &'a mut u8, tail: &'a mut [u8]) -> Self

Constructor of a message buffer around exclusive memory.

This is a short-cut for creating a SliceBufferMut and passing it to Self::new_empty().

pub fn new_from_encoded_slice( code: &'a mut u8, tail: &'a mut [u8], ) -> Result<Self, ParsingError>

Creates a MutableWritableMessage on a buffer that already contains a serialized message.

While this is generally not useful (as the message has been completed and there is no room for anything more), it allows mutable access to the option bytes and the payload. This is primarily useful in situations when data is processed in place, eg. decrypted (in OSCORE), or CBOR is shifted around to get contiguous slices out of indefinite length strings.

If the message has been parsed as a Message around a mutable back-end before, it is preferable to use its .into_mutable() method, as that can avoid the full parsing that is needed to uphold this type’s guarantees.

Errors

… are returned if the input slice does not contain a well-formed message.

Source

impl<T: MessageBufferMut> MessageMut<T>

pub fn new_empty(encoded: T) -> Self

Constructor of a message buffer around any MessageBufferMut.

pub fn downcast_from<M: MinimalWritableMessage>( generic: &mut M, ) -> Option<&mut Self>

Available on crate feature downcast only.

Returns a full Self from input that is expected (but not known at type level) to be one.

Source

impl<EM: MessageBufferMut> MessageMut<EM>

pub fn insert_option( &mut self, number: u16, data: &[u8], ) -> Result<(), WriteError>

Inserts an option.

This behaves similarly to add_option(), but without the limitation of needing to uphold option ordering manually.

This comes at the cost of iterating over all options and re-encoding one.

Errors

This function returns a WriteError if there isn’t sufficient space left for the insertion.

pub fn retain_options<P>(&mut self, predicate: P)
where P: Fn(u16, &[u8]) -> bool,

Retains all options the predicate applies to, the rest will be removed.

pub fn reset(&mut self)

Discards anything that has been written in the message, and allows any operation that would be allowed after calling Self::new_empty().

This is a short-cut to messages that can be snapshotted and rewound, and a band-aid until that is available in traits.

pub fn untruncate(&mut self, added_len: usize) -> Result<(), WriteError>

Expands the bounds of the payload by added_len.

Similar to payload_mut_with_len(), but it has no restriction on length (beyond the length of the underlying buffer).

Errors

… are raised if there is insufficient space for extending the payload.

pub fn finish(self) -> (usize, EM)

Returns the number of bytes that were populated inside tail, along with the encoded data.

For EMs that are just referenced (i.e., slices), the 2nd output can often just be discarded, but it is essential for owned ones.