ParsingError

Struct ParsingError 

pub struct ParsingError(/* private fields */);
Error type indicating a malformed CoAP message.

While usually, Message does not err on parsing trouble as per its documentation (it maps the exotic error case into the more regular error case that needs to be handled by the user anyway), but in rare cases it does need to err (e.g. when converting to a MessageMut that has an internal invariant on well-formedness).