Crate coap_message_implementations

Crate coap_message_implementations 

CoAP message implementation tools and implementations

This crate contains utilities for creating own implementations of the coap_message traits, as well as some basic implementations that may be useful for CoAP libraries.

The implementations aim for being easy and straightforward. While they are largely usable on embedded systems, it is expected that more optimized versions are used in that area when byte comes to shove.

Feature flags

  • alloc — Enable the heap module with its heap::HeapMessage implementation.
  • downcast — Enable various downcast_from() methods. This is feature gated because it is the only place in the crate that uses unsafe code, allowing users who do not need it (it is a niche feature) more trust in the crate’s correctness.

Modules

heapalloc
This module provides HeapMessage, an implementation of all the message traits backed by heap memory.
inmemory
Implementations of coap_message traits based on a serialized messages.
option_extension
Tools for handling the extension encoding of CoAP options
option_iteration
Tools for iterating over encoded messages