Implementation of coap_message::ReadableMessage based on a serialized message
Message is the main struct of this module – if the message is available as a slice that
lives as long as the message, that’s the type to use. Otherwise, implement EncodedMessage on
your data, and wrap it in an EncodedMessageView. (The Message is nothing else than the
options/payload slice plus the code in a struct).
Note that the crate::inmemory_write has a similar mechanism but does without an equivalent
“view”; at the next breaking revision, those might be unified.
Structs
- Encoded
Message View - A wrapper around any data structure containing a readable message
- Message
- A CoAP message that resides in contiguous readable memory
- Message
Option - A simple
coap_message::MessageOptionimplementation for memory-mapped CoAP messages - Options
Iter - An iterator producing
MessageOptions by running along an encoded CoAP message options stream by using aOptPayloadReaderand discarding the payload.
Constants
- OPTION_
INVALID - Option value used by this library to indicate a format error in the message that was not detected by the time option / payload processing was started.
Traits
- Encoded
Message - A trait that can implemented on in-memory encoded messages; then, an
EncodedMessageViewstruct can be placed around the implementer to implementcoap_message::ReadableMessage.