pub struct Message<EM: MessageBuffer> { /* private fields */ }Expand description
A CoAP message that resides in contiguous readable memory.
This implementation does not attempt to do any early validation. On encoding errors discovered
at runtime, it simply emits the critical-and-not-safe-to-forward CoAP option 65535
(OPTION_INVALID), which to the indication indicates that something went wrong
Message is covariant over its lifetime because it only reads from there, effectively
fulfilling the expectations of LifetimesMatterLittle. That
property is currently not exposed.
Implementation details
When used with coap_message::helpers::RefWithStaticType, it always uses Message<EMS>
where EMS is the type inside the LifetimesMatterLittle of the EM::static_variant()
result. This is needed to run Self::downcast_from, and restores the lifetime based on the
given impl Trait reference’s lifetime using its covariance property.
Implementations
Sourceimpl<'a> Message<SliceBuffer<'a>>
impl<'a> Message<SliceBuffer<'a>>
Sourcepub fn new_from_slice(code: u8, options_and_payload: &'a [u8]) -> Self
pub fn new_from_slice(code: u8, options_and_payload: &'a [u8]) -> Self
Creates a message that is parsed from a slice.
This is a short-cut for creating a SliceBuffer and passing it to Self::new().
Sourceimpl<EM: MessageBuffer> Message<EM>
impl<EM: MessageBuffer> Message<EM>
Sourcepub fn new(inner: EM) -> Self
pub fn new(inner: EM) -> Self
Creates a new instance backed by an encoded message buffer.
Decoding assumes that the full tail of the buffer contains options and payload.
Sourcepub fn new_until(inner: EM, length: usize) -> Self
pub fn new_until(inner: EM, length: usize) -> Self
Creates a new instance backed by an encoded message buffer.
Decoding assumes that the first length bytes contain options and payload. (The buffer
having the option to be longer is mostly useful when it is also an
MessageBufferMut, and might later get
turned .into_mutable()).
pub fn downcast_from<M: ReadableMessage>(generic: &M) -> Option<&Self>
downcast only.Sourcepub fn into_mutable(self) -> Result<MessageMut<EM>, ParsingError>where
EM: MessageBufferMut,
pub fn into_mutable(self) -> Result<MessageMut<EM>, ParsingError>where
EM: MessageBufferMut,
Converts the message into a mutable writable message.
This can be useful to reuse a buffer that has been passed to the application, e.g. for in-place decryption or to shove around indefinite-length CBOR encoding inside payloads.
Errors
… are only raised if the message contains parsing errors (for a mutable message is stricter in that regard).